from os import getenv, path
from argparse import ArgumentParser
import subprocess

from kombu import Queue, Exchange
from celery import Celery


parser = ArgumentParser()
parser.add_argument('-n', '--hostname', dest='hostname',
                    help='Define the full queue name with'
                    'with priority', metavar='hostname.queue')
(args, unknwon_args) = parser.parse_known_args()
HOSTNAME = vars(args).pop('hostname')
if HOSTNAME is None:
    raise Exception('You must define hostname as -n <hostname> or '
                    '--hostname=<hostname>.\n'
                    'Hostname format must be hostname.queue.')


AMQP_URI = getenv('AMQP_URI')
DNS_DB_DIR = getenv('DNS_DB_DIR', '/var/lib/circle/dnsdriver')

celery = Celery('dnsdriver', broker=AMQP_URI)
celery.conf.update(
    CELERY_RESULT_BACKEND='amqp',
    CELERY_TASK_RESULT_EXPIRES=300,
    CELERY_QUEUES=(
        Queue(HOSTNAME, Exchange(
              'dnsdriver', type='direct'), routing_key='dnsdriver'),
    )
)


@celery.task(name='firewall.reload_dns')
def reload_dns(data):
    with open(path.join(DNS_DB_DIR, 'data'), 'w') as f:
        f.write('\n'.join(data))
    process = subprocess.Popen(['make', '-C', DNS_DB_DIR],
                               shell=False, stdin=subprocess.PIPE)
    process.communicate('\n'.join(data) + '\n')
